/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { BaseClient, ClientConfig, Response } from "@commerce-apps/core";
import { OperationOptions } from "retry";
import {
  RevokeTokenRequestT,
  IntrospectResponseT,
  ErrorResponseT,
  IntrospectTokenRequestT,
  TokenResponseT,
  TokenRequestT,
  SearchRequestT,
  PaginatedSearchResultT,
  SimpleSearchResultT,
  BoolFilterT,
  MatchAllQueryT,
  FilteredQueryT,
  QueryFilterT,
  QueryT,
  TermQueryT,
  TermFilterT,
  TextQueryT,
  Range2FilterT,
  BoolQueryT,
  NestedQueryT,
  FilterT,
  SortT,
  RangeFilterT
} from "./shopperLoginApiAuthNSlas.types";
/**
 * Instantiate a Client object with desired ClientConfig to perform operations
 * available in this API client.
 *
 * Note: When performing operations that require ShopperJWT authentication, an
 * Authorization header containing a JWT can be added to the headers field of the
 * ClientConfig object. The Client will use that Authorization header for all the
 * operations it is used to perform.
 */
declare class ShopperLoginApiAuthNSlas extends BaseClient {
  constructor(config: ClientConfig);
  /**
   * Get authorization code after authenticating a user against an IDP. This is the first step of the Authorization code grant flow, where a user is able to login via federation to the IDP configured for the client, and gets an authorization code after succesful login via a callback/redirect URI. Mandatory fields are the shopping app's clientId, redirectURI, responseType and authType. This API can be called from the front channel (from the browser).
   *
   * If you would like to get a raw Response object use the other authorizeCustomer function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param redirectUri - The URL to which the server redirects the browser after the user grants the authorization.  The URI must be pre-registered.
   * @param responseType - Must be 'code'.  'code' indicates that the client wants an authorization code (authorization code grant flow).
   * @param clientId - The client id obtained during application registration.
   * @param scope - (Not Supported)
   * @param state - Value to be sent by the client to determine the state between the authorization request and the server response.  Optional but strongly recommended.
   * @param uuid - Id that uniquely identifies the shopper. This is an optional field, a new UUID will be generated if this field is empty.
   * @param hint - Idp name that can be optionally added to redirect directly to skipping the Idp selection step.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type void.
   */
  authorizeCustomer(options?: {
    parameters?: {
      organizationId?: string;
      redirectUri: string;
      responseType: string;
      clientId?: string;
      scope?: string;
      state?: string;
      uuid?: string;
      hint?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<void>;
  /**
   * Get authorization code after authenticating a user against an IDP. This is the first step of the Authorization code grant flow, where a user is able to login via federation to the IDP configured for the client, and gets an authorization code after succesful login via a callback/redirect URI. Mandatory fields are the shopping app's clientId, redirectURI, responseType and authType. This API can be called from the front channel (from the browser).
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param redirectUri - The URL to which the server redirects the browser after the user grants the authorization.  The URI must be pre-registered.
   * @param responseType - Must be 'code'.  'code' indicates that the client wants an authorization code (authorization code grant flow).
   * @param clientId - The client id obtained during application registration.
   * @param scope - (Not Supported)
   * @param state - Value to be sent by the client to determine the state between the authorization request and the server response.  Optional but strongly recommended.
   * @param uuid - Id that uniquely identifies the shopper. This is an optional field, a new UUID will be generated if this field is empty.
   * @param hint - Idp name that can be optionally added to redirect directly to skipping the Idp selection step.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   */
  authorizeCustomer<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        redirectUri: string;
        responseType: string;
        clientId?: string;
        scope?: string;
        state?: string;
        uuid?: string;
        hint?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
   * Get the shopper or guest JWT/access token along with a refresh token. This is the second step of the OAuth2 Authorization code flow where a client app is able to get an access token for the shopper through the backchannel (a trusted server side) by passing in the client credentials and the authorization code retrieved from authorize endpoint. Mandatory fields when using the token endpoint to get the accesstoken are clientId, clientSecret, authorizationCode, grantType of authorization_code. \<br/\>\<br/\> As a guest user get the shopper JWT / access token along with a refresh token. This is where a client app is able to get an access token for the guest user through the back-channel (a trusted server side) by passing in the client credentials. Mandatory fields when asking for the guest token endpoint to get the access token are clientId, clientSecret, grantType of client_credentials.\<br/\>\<br/\> Mandatory fields when using using the token endpoint to refresh an access token are refreshToken, grantType of refresh_token.
   *
   * If you would like to get a raw Response object use the other getAccessToken function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type TokenResponseT.
   */
  getAccessToken(options: {
    parameters?: {
      organizationId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: TokenRequestT;
  }): Promise<TokenResponseT>;
  /**
   * Get the shopper or guest JWT/access token along with a refresh token. This is the second step of the OAuth2 Authorization code flow where a client app is able to get an access token for the shopper through the backchannel (a trusted server side) by passing in the client credentials and the authorization code retrieved from authorize endpoint. Mandatory fields when using the token endpoint to get the accesstoken are clientId, clientSecret, authorizationCode, grantType of authorization_code. \<br/\>\<br/\> As a guest user get the shopper JWT / access token along with a refresh token. This is where a client app is able to get an access token for the guest user through the back-channel (a trusted server side) by passing in the client credentials. Mandatory fields when asking for the guest token endpoint to get the access token are clientId, clientSecret, grantType of client_credentials.\<br/\>\<br/\> Mandatory fields when using using the token endpoint to refresh an access token are refreshToken, grantType of refresh_token.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type TokenResponseT otherwise.
   */
  getAccessToken<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: TokenRequestT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : TokenResponseT>;
  /**
   * Invalidate the refresh token. A basic auth header with base64 encoded clientId:secret is required in the Authorization header and the refresh token to be revoked is required in the body.
   *
   * If you would like to get a raw Response object use the other revokeToken function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type Object.
   */
  revokeToken(options: {
    parameters?: {
      organizationId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: RevokeTokenRequestT;
  }): Promise<Record<string, any>>;
  /**
   * Invalidate the refresh token. A basic auth header with base64 encoded clientId:secret is required in the Authorization header and the refresh token to be revoked is required in the body.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type Object otherwise.
   */
  revokeToken<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: RevokeTokenRequestT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : Record<string, any>>;
}
declare namespace ShopperLoginApiAuthNSlas {
  type RevokeTokenRequest = RevokeTokenRequestT;
  type IntrospectResponse = IntrospectResponseT;
  type ErrorResponse = ErrorResponseT;
  type IntrospectTokenRequest = IntrospectTokenRequestT;
  type TokenResponse = TokenResponseT;
  type TokenRequest = TokenRequestT;
  type SearchRequest = SearchRequestT;
  type PaginatedSearchResult = PaginatedSearchResultT;
  type SimpleSearchResult = SimpleSearchResultT;
  type BoolFilter = BoolFilterT;
  type MatchAllQuery = MatchAllQueryT;
  type FilteredQuery = FilteredQueryT;
  type QueryFilter = QueryFilterT;
  type Query = QueryT;
  type TermQuery = TermQueryT;
  type TermFilter = TermFilterT;
  type TextQuery = TextQueryT;
  type Range2Filter = Range2FilterT;
  type BoolQuery = BoolQueryT;
  type NestedQuery = NestedQueryT;
  type Filter = FilterT;
  type Sort = SortT;
  type RangeFilter = RangeFilterT;
}
export = ShopperLoginApiAuthNSlas;
